kerneltest/f32test/filesystem/fat/t_mount.cpp
branchRCL_3
changeset 257 3e88ff8f41d5
parent 256 c1f20ce4abcf
child 268 345b1ca54e88
--- a/kerneltest/f32test/filesystem/fat/t_mount.cpp	Tue Aug 31 16:34:26 2010 +0300
+++ b/kerneltest/f32test/filesystem/fat/t_mount.cpp	Wed Sep 01 12:34:56 2010 +0100
@@ -629,12 +629,12 @@
     bDriveFinalised = DoCheckVolumeFinalised(gDriveNum);
     test(!bDriveFinalised); //-- the volume has become "unfinalised"
 
     //-- 2.1 open a file, try to finalise; This should be OK
     nRes = file.Replace(TheFs, KFileName, EFileWrite | EFileRead);
     test_KErrNone(nRes);
 
     nRes =TheFs.FinaliseDrive(gDriveNum, RFs::EFinal_RW);
-    test_KErrNone(nRes);
+    test(nRes==KErrInUse); //-- can't finalise drives with opened objects
 
     file.Close();
 
@@ -1274,6 +1274,7 @@
     PrintDrvInfo(TheFs, gDriveNum);
     InitGlobals();
 
+
     TestNotifyDiskSpace();
 
     //-------------------------------------
@@ -629,12 +629,12 @@
     test(!bDriveFinalised); //-- the volume has become "unfinalised"
 
-    //-- 2.1 open a file, try to finalise; This should be OK
+    //-- 2.1 open a file, try to finalise; Shall dail with KErrInUse
     nRes = file.Replace(TheFs, KFileName, EFileWrite | EFileRead);
     test_KErrNone(nRes);